/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.test.webid;

import java.net.Socket;
import java.security.Principal;
import java.security.PrivateKey;
import java.security.cert.X509Certificate;

import javax.net.ssl.X509ExtendedKeyManager;

import org.bergnet.webid.commons.WebID;

public class WebIDClientKeyManager extends X509ExtendedKeyManager {
	private WebID webid;

	public WebIDClientKeyManager(WebID webid) {
		this.webid = webid;
	}
	public String chooseClientAlias(String[] keyType, Principal[] issuers, Socket socket) {
		return "webid";
	}

	public String chooseServerAlias(String keyType, Principal[] issuers, Socket socket) {
		return null;
	}

	public X509Certificate[] getCertificateChain(String alias) {
		if("webid".equals(alias))
			return new X509Certificate[] { webid.getCertificate() };
		else
			return null;
	}

	public String[] getClientAliases(String keyType, Principal[] issuers) {
		return new String[] { "webid" };
	}

	public PrivateKey getPrivateKey(String alias) {
		return webid.getPrivateKey();
	}

	public String[] getServerAliases(String keyType, Principal[] issuers) {
		return new String[] {};
	}
}