/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.webid.commons;

import java.math.BigInteger;

public class FOAFBuilder {
	public static final String FORMAT_RDF_XML = "application/rdf+xml";
	public static final String FORMAT_TURTLE = "text/turtle";

	public static String build(WebID webid, String format) throws WebIDException {
		return build(webid.getUris(), webid.getModulus(), webid.getPublicExponent(), format);
	}

	public static String build(String[] uris, BigInteger modulus, BigInteger publicExponent, String format) {
		if(FORMAT_TURTLE.equals(format))
			return buildTurtle(uris, modulus, publicExponent);
		else
			return buildRdfXml(uris, modulus, publicExponent);
	}

	public static String buildRdfXml(String[] uris, BigInteger modulus, BigInteger publicExponent) {
		StringBuilder rdfStringBuilder = new StringBuilder();

		rdfStringBuilder.append("<rdf:RDF xmlns:cert=\"http://www.w3.org/ns/auth/cert#\" xmlns:foaf=\"http://xmlns.com/foaf/0.1/\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:rsa=\"http://www.w3.org/ns/auth/rsa#\">\n");
		rdfStringBuilder.append("<rsa:RSAPublicKey>\n");
		rdfStringBuilder.append("<rsa:modulus rdf:datatype=\"http://www.w3.org/ns/auth/cert#hex\">" + modulus.toString(16) + "</rsa:modulus>\n");
		rdfStringBuilder.append("<rsa:public_exponent rdf:datatype=\"http://www.w3.org/ns/auth/cert#decimal\">" + publicExponent.toString(10) + "</rsa:public_exponent>\n");

		for(String uri : uris)
			rdfStringBuilder.append("<cert:identity rdf:resource=\"" + uri + "\" />\n");

		rdfStringBuilder.append("</rsa:RSAPublicKey>\n");
		rdfStringBuilder.append("</rdf:RDF>");

		return rdfStringBuilder.toString();
	}
	
	public static String buildTurtle(String[] uris, BigInteger modulus, BigInteger publicExponent) {
		StringBuilder rdfStringBuilder = new StringBuilder();

		rdfStringBuilder.append("@prefix cert: <http://www.w3.org/ns/auth/cert#>.\n");
		rdfStringBuilder.append("@prefix rsa: <http://www.w3.org/ns/auth/rsa#>.\n");
		rdfStringBuilder.append("\n");
		rdfStringBuilder.append("[] a rsa:RSAPublicKey;\n");
		rdfStringBuilder.append("\trsa:modulus \"" + modulus.toString(16) + "\"^^cert:hex;\n");
		rdfStringBuilder.append("\trsa:public_exponent \"" + publicExponent.toString(10) + "\"^^cert:int;\n");

		for(int i=0; i<uris.length; i++) {
			if(i != uris.length-1)
				rdfStringBuilder.append("\tcert:identity <" + uris[i] + ">;\n");
			else
				rdfStringBuilder.append("\tcert:identity <" + uris[i] + ">.\n");
		}

		return rdfStringBuilder.toString();
	}
}
