/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.webid.commons;

import java.io.FileWriter;
import java.io.IOException;
import java.util.Date;


public class WebIDTool {
	public static final String OPTION_ALIAS = "alias";
	public static final String OPTION_GENERATE = "generate";
	public static final String OPTION_IN = "in";
	public static final String OPTION_KEY_SIZE = "keysize";
	public static final String OPTION_MAX_AGE = "maxage";
	public static final String OPTION_OUT = "out";
	public static final String OPTION_OUT_FOAF = "outfoaf";
	public static final String OPTION_PASSWORD = "password";
	public static final String OPTION_URIS = "uris";


	public static void writeFoafFile(WebID webid, String fileName, String format) throws WebIDException {
		try {
			FileWriter fileWriter = new FileWriter(fileName);
			fileWriter.write(FOAFBuilder.build(webid, format));
			fileWriter.close();
		} catch (IOException e) {
			throw new WebIDException("Couldn't write FOAF file", e);
		}
	}

	public static void main(String[] args) throws Exception {
		String alias = null;
		boolean generate = false;
		String in = null;
		int keySize = 1024;
		int maxAge = 365;
		String out = null;
		String outFoaf = null;
		String password = null;
		String uris[] = null;
		String foafFormat = FOAFBuilder.FORMAT_RDF_XML;

		WebID webid = null;

		int argIndex = 0;

		while(args.length > argIndex) {
			String arg = args[argIndex];

			if(!arg.startsWith("-"))
				continue;

			arg = arg.substring(1);

			if(OPTION_ALIAS.equals(arg)) {
				alias = args[++argIndex];
			} else if(OPTION_GENERATE.equals(arg)) {
				generate = true;
			} else if(OPTION_IN.equals(arg)) {
				in = args[++argIndex];
			} else if(OPTION_KEY_SIZE.equals(arg)) {
				keySize = Integer.valueOf(args[++argIndex], 10);
			} else if(OPTION_MAX_AGE.equals(arg)) {
				maxAge = Integer.valueOf(args[++argIndex], 10);
			} else if(OPTION_OUT.equals(arg)) {
				out = args[++argIndex];
			} else if(OPTION_OUT_FOAF.equals(arg)) {
				outFoaf = args[++argIndex];
			} else if(OPTION_PASSWORD.equals(arg)) {
				password = args[++argIndex];
			} else if(OPTION_URIS.equals(arg)) {
				uris = args[++argIndex].split(",");
			} else {
				throw new Exception("unknown paramter: " + arg);
			}

			argIndex++;
		}
		
		if(generate) {
			webid = WebID.generate(keySize, uris, new Date(), WebID.createDeltaDate(maxAge));
		} else if(in != null) {
			webid = CryptoUtils.readPkcs12File(in, alias, password);
		} else {
			WebIDToolSwingGUI.main(new String[] {});
		}

		if(webid != null && out != null)
			CryptoUtils.writePkcs12File(webid, out, alias, password);

		if(webid != null && outFoaf != null) {
			if(uris != null && uris.length > 0)
				writeFoafFile(webid, outFoaf, foafFormat);
			else
				writeFoafFile(webid, outFoaf, foafFormat);
		}
	}
}
